@@ -1,6 +1,6 @@
 .NAMES = LETTERS[c(1:8, 10:26)]
-setClass("doeFactor", representation = representation(low = "ANY", high = "ANY", name = "character", unit = "character", 
-    type = "character"), prototype = prototype(low = -1, high = 1, name = "", unit = "", type = "numeric"))
+setClass("doeFactor", representation = representation(low = "ANY", high = "ANY", name = "character", unit = "character", type = "character"), prototype = prototype(low = -1, 
+    high = 1, name = "", unit = "", type = "numeric"))
 setGeneric(".low", function(object) standardGeneric(".low"))
 setGeneric(".low<-", function(x, value) standardGeneric(".low<-"))
 setMethod(".low", "doeFactor", function(object) unlist(object@low))
@@ -62,10 +62,9 @@ setMethod("show", signature(object = "doeFactor"), function(object) {
     cat("type: ", .type(object), "\n")
     cat("\n")
 })
-setClass(Class = "facDesign", representation = representation(name = "character", factors = "list", cube = "data.frame", 
-    star = "data.frame", centerCube = "data.frame", centerStar = "data.frame", generator = "ANY", response = "data.frame", 
-    block = "data.frame", blockGen = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", desireVal = "list", 
-    desirability = "list", fits = "list"))
+setClass(Class = "facDesign", representation = representation(name = "character", factors = "list", cube = "data.frame", star = "data.frame", centerCube = "data.frame", 
+    centerStar = "data.frame", generator = "ANY", response = "data.frame", block = "data.frame", blockGen = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", 
+    desireVal = "list", desirability = "list", fits = "list"))
 setGeneric(".nfp", function(object) standardGeneric(".nfp"))
 setMethod(".nfp", "facDesign", function(object) {
     x = factors(object)
@@ -512,8 +511,7 @@ setReplaceMethod("response", "facDesign", function(object, value) {
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(response(object)) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
-                " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), " "))
         object@response <- data.frame(value)
         object@response[index, ] <- value
         names(object@response) = make.names(deparse(substitute(value)))
@@ -540,8 +538,7 @@ setReplaceMethod("blockGen", "facDesign", function(object, value) {
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(object) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
-                " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), " "))
         object@blockGen <- as.data.frame(value)
         names(blockGen(object)) = deparse(substitute(value))
         object
@@ -566,8 +563,7 @@ setReplaceMethod("block", "facDesign", function(object, value) {
         stop("vector or data.frame expected!")
     if (is.vector(value) && (is.numeric(value) || is.na(value))) {
         if (nrow(object) != length(value)) 
-            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), 
-                " "))
+            stop(paste("Number of rows for Design does not equal length of vector ", nrow(object), " != ", length(value), " "))
         object@block <- as.data.frame(value)
         names(block(object)) = deparse(substitute(value))
         object
@@ -630,7 +626,6 @@ setMethod("as.data.frame", "facDesign", function(x, row.names = NULL, optional =
         names(frameOut) = as.character(names(names(x)))
     }
     if (nrow(blockGen(x)) > 0) {
-        frameOut = cbind(blockGen(x), frameOut)
     }
     if (nrow(block(x)) > 0) {
         frameOut = cbind(block(x), frameOut)
@@ -667,7 +662,6 @@ as.data.frame.facDesign = function(x, row.names = NULL, optional = FALSE, ...) {
         names(frameOut) = as.character(names(names(x)))
     }
     if (nrow(blockGen(x)) > 0) {
-        frameOut = cbind(blockGen(x), frameOut)
     }
     if (nrow(block(x)) > 0) {
         frameOut = cbind(block(x), frameOut)
@@ -891,8 +885,7 @@ confounds = function(x, depth = 2) {
     }
     cat("\nAlias Structure:\n")
     for (i in 1:length(effect1)) {
-        if ((length(strsplit(effect1[i], split = character(0))[[1]]) <= depth) && (length(strsplit(effect2[i], split = character(0))[[1]]) <= 
-            depth)) 
+        if ((length(strsplit(effect1[i], split = character(0))[[1]]) <= depth) && (length(strsplit(effect2[i], split = character(0))[[1]]) <= depth)) 
             cat(effect1[i], "\tis confounded with\t", effect2[i], "\n")
         if (identical(depth, "all")) 
             cat(effect1[i], "\tis confounded with\t", effect2[i], "\n")
@@ -1065,18 +1058,17 @@ fracDesign = function(k = 3, gen = NULL, replicates = 1, blocks = 1, centerCube
     runOrd(DesignOut) = runOrder
     if (DB) 
         print("3")
-    if (blocks == 1) {
-        Block = data.frame(Block = rep(1, times = numRows))
-        block(DesignOut) = Block
-    }
     if (centerCube >= 1) {
         temp = data.frame(matrix(rep(0, centerCube * k), ncol = k, nrow = centerCube))
         names(temp) = names(frameOut)
         centerCube(DesignOut) = temp
     }
-    return(DesignOut)
+    temp = try(blocking(DesignOut, blocks = blocks))
+    if (inherits(temp, "try-error")) 
+        return(DesignOut)
+    return(blocking(DesignOut, blocks = blocks))
 }
 facDesign = function(k = 3, replicates = 1, blocks = 1, centerCube = 0) {
-    frameOut = fracDesign(k = k, gen = NULL, replicates = replicates, blocks = 1, centerCube = centerCube)
+    frameOut = fracDesign(k = k, gen = NULL, replicates = replicates, blocks = blocks, centerCube = centerCube)
     return(frameOut)
 } 
