@@ -131,8 +131,11 @@ setMethod(effectPlot, signature(object = "facDesign"), function(object, factors,
                 xlab = factors[i]
                 xlabmiss = TRUE
             }
-            if (xlabmiss) 
-                xlab = factors[i]
+            if (xlabmiss) {
+                if (identical(" ", names(object)[[i]])) 
+                  xlab = factors[i]
+                else xlab = paste(factors[i], ": ", names(object)[[i]], sep = "")
+            }
             if (missing(ylab)) {
                 ylab = paste(deparse(substitute(fun)), "of ", names(Y)[j])
                 ylabmiss = TRUE
@@ -148,14 +151,18 @@ setMethod(effectPlot, signature(object = "facDesign"), function(object, factors,
             if (classic) {
                 .m.interaction.plot(x.factor = X[, factors[i]], trace.factor = rep(0, nrow(X)), response = Y[, j], lty = lty, ylim = ylim, xlab = xlab, fun = fun, 
                   ylab = ylab, legend = FALSE, axes = FALSE, main = " ", ...)
+                grid(NA, 2)
                 axis(1, at = X[, factors[i]])
                 if (i == 1) 
                   axis(2)
                 box()
                 title(main, outer = TRUE)
             }
-            else .m.interaction.plot(x.factor = X[, factors[i]], trace.factor = rep(0, nrow(X)), response = Y[, j], lty = lty, ylim = ylim, xlab = xlab, fun = fun, 
-                ylab = ylab, legend = FALSE, axes = axes, main = main, ...)
+            else {
+                .m.interaction.plot(x.factor = X[, factors[i]], trace.factor = rep(0, nrow(X)), response = Y[, j], lty = lty, ylim = ylim, xlab = xlab, fun = fun, 
+                  ylab = ylab, legend = FALSE, axes = axes, main = main, ...)
+                grid(NA, 2)
+            }
             if (points) 
                 points(X[, factors[i]], Y[, j], ...)
             counter = counter + 1
@@ -233,8 +240,11 @@ setMethod(effectPlot, signature(object = "taguchiDesign"), function(object, fact
                 xlab = factors[i]
                 xlabmiss = TRUE
             }
-            if (xlabmiss) 
-                xlab = factors[i]
+            if (xlabmiss) {
+                if (identical(" ", names(object)[[i]])) 
+                  xlab = factors[i]
+                else xlab = paste(factors[i], ": ", names(object)[[i]], sep = "")
+            }
             if (missing(ylab)) {
                 ylab = paste(deparse(substitute(fun)), "of ", names(Y)[j])
                 ylabmiss = TRUE
@@ -250,14 +260,18 @@ setMethod(effectPlot, signature(object = "taguchiDesign"), function(object, fact
             if (classic) {
                 .m.interaction.plot(x.factor = X[, factors[i]], trace.factor = rep(0, nrow(X)), response = Y[, j], lty = lty, ylim = ylim, xlab = xlab, fun = fun, 
                   ylab = ylab, legend = FALSE, axes = FALSE, main = " ", ...)
+                grid(NA, 2)
                 axis(1, at = X[, factors[i]])
                 if (i == 1) 
                   axis(2)
                 box()
                 title(main, outer = TRUE)
             }
-            else .m.interaction.plot(x.factor = X[, factors[i]], trace.factor = rep(0, nrow(X)), response = Y[, j], lty = lty, ylim = ylim, xlab = xlab, fun = fun, 
-                ylab = ylab, legend = FALSE, axes = axes, main = main, ...)
+            else {
+                .m.interaction.plot(x.factor = X[, factors[i]], trace.factor = rep(0, nrow(X)), response = Y[, j], lty = lty, ylim = ylim, xlab = xlab, fun = fun, 
+                  ylab = ylab, legend = FALSE, axes = axes, main = main, ...)
+                grid(NA, 2)
+            }
             if (points) 
                 points(X[, factors[i]], Y[, j], ...)
             counter = counter + 1
