@@ -7,7 +7,7 @@
         x = x[, 1]
     dots = list(...)
     parameter = NULL
-    smaller = TRUE
+    smaller = NULL
     pFun = NULL
     tableValue = FALSE
     A = 0
@@ -53,6 +53,30 @@
     else {
         pval <- exp(1.2937 - 5.709 * AA + 0.0186 * AA^2)
     }
+    if (identical(distribution, "cauchy")) {
+        pval = NA
+    }
+    if (identical(distribution, "beta")) {
+        pval = NA
+    }
+    if (identical(distribution, "chi-squared")) {
+        pval = NA
+    }
+    if (identical(distribution, "f")) {
+        pval = NA
+    }
+    if (identical(distribution, "t")) {
+        pval = NA
+    }
+    if (identical(distribution, "geometric")) {
+        pval = NA
+    }
+    if (identical(distribution, "poisson")) {
+        pval = NA
+    }
+    if (identical(distribution, "negative-binomial")) {
+        pval = NA
+    }
     if (identical(distribution, "weibull")) {
         AWei = A * (1 + 1/sqrt(n))
         tableValue = TRUE
@@ -74,7 +98,20 @@
     }
     if (identical(distribution, "exponential")) {
         tableValue = TRUE
-        return(paste("Sorry, not yet supported!"))
+        AExp = A * (1 + 0.6/n)
+        pval = NA
+        if (0.95 < AExp) {
+            pval = exp(0.731 - 3.009 * AExp + 0.15 * AExp^2)
+        }
+        if (0.51 < AExp & AExp < 0.95) {
+            pval = exp(0.9209 - 3.353 * AExp + 0.3 * AExp^2)
+        }
+        if (0.26 < AExp & AExp < 0.51) {
+            pval = 1 - exp(-6.1327 + 20.218 * AExp - 18.663 * AExp^2)
+        }
+        if (AExp < 0.26) {
+            pval = 1 - exp(-12.2204 + 67.459 * AExp - 110.3 * AExp^2)
+        }
     }
     if (identical(distribution, "logistic")) {
         ALogist = A * (1 + 0.25/n)
@@ -105,9 +142,25 @@
     }
     if (identical(distribution, "gamma")) {
         tableValue = TRUE
-        print("TODO: gamma function")
-        pval = NA
-        smaller = FALSE
+        gammaDF = data.frame(c(1, 2, 3, 4, 5, 6, 8, 10, 12, 15, 20, Inf), c(0.486, 0.477, 0.475, 0.473, 0.472, 0.472, 0.471, 0.471, 0.471, 0.47, 0.47, 0.47), 
+            c(0.657, 0.643, 0.639, 0.637, 0.635, 0.635, 0.634, 0.633, 0.633, 0.632, 0.632, 0.631), c(0.786, 0.768, 0.762, 0.759, 0.758, 0.757, 0.755, 0.754, 
+                0.754, 0.754, 0.753, 0.752), c(0.917, 0.894, 0.886, 0.883, 0.881, 0.88, 0.878, 0.877, 0.876, 0.876, 0.875, 0.873), c(1.092, 1.062, 1.052, 1.048, 
+                1.045, 1.043, 1.041, 1.04, 1.039, 1.038, 1.037, 1.035), c(1.227, 1.19, 1.178, 1.173, 1.17, 1.168, 1.165, 1.164, 1.163, 1.162, 1.161, 1.159))
+        names(gammaDF) = c("m", 0.75, 0.9, 0.95, 0.975, 0.99, 0.995)
+        critCheck <- gammaDF[min(which(gammaDF$m >= parameter["shape"])), 2:length(gammaDF)] >= A
+        if (any(critCheck)) {
+            firPos <- min(which(critCheck))
+            pValue <- 1 - as.numeric(names(gammaDF)[firPos])
+            pval = pValue
+            pValue <- paste("<=", pValue)
+            smaller = TRUE
+        }
+        else {
+            pValue <- 1 - as.numeric(names(gammaDF)[length(gammaDF)])
+            pval = pValue
+            pValue <- paste(">", pValue)
+            smaller = FALSE
+        }
     }
     out = list()
     out$data.name = data.name
@@ -163,8 +216,7 @@ print.adtest = function(x, digits = 4, quote = TRUE, prefix = "", ...) {
         }
     }
     if (!is.null(x$conf.int)) {
-        cat(format(100 * attr(x$conf.int, "conf.level")), "percent confidence interval:\n", format(c(x$conf.int[1L], x$conf.int[2L])), 
-            "\n")
+        cat(format(100 * attr(x$conf.int, "conf.level")), "percent confidence interval:\n", format(c(x$conf.int[1L], x$conf.int[2L])), "\n")
     }
     if (!is.null(x$estimate)) {
         cat("sample estimates:\n")
