@@ -27,7 +27,7 @@
     }
     return(.starFrame)
 }
-rsmDesign = function(k = 3, p = 0, alpha = "rotatable", blocks = 1, cc = 1, cs = 1, faceCentered = FALSE) {
+rsmDesign = function(k = 3, p = 0, alpha = "rotatable", blocks = 1, cc = 1, cs = 1, fp = 1, sp = 1, faceCentered = FALSE) {
     DB = FALSE
     if (blocks > 2^(k - 1) + 1) 
         stop("Blocking not possible")
@@ -65,7 +65,7 @@ rsmDesign = function(k = 3, p = 0, alpha = "rotatable", blocks = 1, cc = 1, cs =
         print(cs)
         print(blocks)
     }
-    fdo = facDesign(k = k)
+    fdo = facDesign(k = k, replicates = fp)
     if (cc > 0) {
         temp = as.data.frame(matrix(0, nrow = cc, ncol = ncol(cube(fdo))))
         names(temp) = names(cube(fdo))
@@ -73,9 +73,17 @@ rsmDesign = function(k = 3, p = 0, alpha = "rotatable", blocks = 1, cc = 1, cs =
         if (DB) 
             print("centerCube")
     }
+    if (DB) 
+        print("star not added")
     temp = .starFrame(k, alpha)
-    names(temp) = names(cube(fdo))
-    star(fdo) = temp
+    starportion = data.frame()
+    for (i in 1:sp) {
+        starportion = rbind(temp, starportion)
+    }
+    names(starportion) = names(cube(fdo))
+    star(fdo) = starportion
+    if (DB) 
+        print("star added")
     if (cs > 0) {
         temp = as.data.frame(matrix(0, nrow = cs, ncol = ncol(cube(fdo))))
         names(temp) = names(cube(fdo))
