@@ -34,11 +34,11 @@ wirePlot = function(x, y, z, data = NULL, xlim, ylim, zlim, main, xlab, ylab, bo
     if (missing(main)) 
         main = paste("Response Surface for", z.c)
     if (missing(ylab)) 
-        ylab = y.c
+        ylab = paste(y.c, ": ", names(fdo)[[y.c]])
     if (missing(xlab)) 
-        xlab = x.c
+        xlab = paste(x.c, ": ", names(fdo)[[x.c]])
     if (missing(zlab)) 
-        zlab = z.c
+        zlab = paste(x.c, ": ", names(response(fdo)))
     if (missing(ticktype)) 
         ticktype = "detailed"
     if (missing(border)) 
@@ -272,9 +272,9 @@ contourPlot = function(x, y, z, data = NULL, xlim, ylim, zlim, main, xlab, ylab,
     if (missing(main)) 
         main = paste("Filled Contour for", z.c)
     if (missing(ylab)) 
-        ylab = y.c
+        ylab = paste(y.c, ": ", names(fdo)[[y.c]])
     if (missing(xlab)) 
-        xlab = x.c
+        xlab = paste(x.c, ": ", names(fdo)[[x.c]])
     if (missing(factors)) 
         factors = NULL
     if (missing(xlim)) 
